# -*- coding: utf-8 -*-
"""
Il modulo contiene una classe in grado di scaricare e auto-generare la lista di
radio e tv partendo da un file remoto.
"""

import urllib
import os

class ListGenerator() :
    """
    Questa classe si occupa del download e della generazione
    dei dizionari contenenti canali Tv e Radio. Queste informazioni
    vengono salvate in una cartella di configurazione all'interno
    della HOME dell'utente.
    """
    
    URL_TV = "http://tvplayersite.altervista.org/online/tv.list"
    URL_RADIO = "http://tvplayersite.altervista.org/online/radio.list"

    URL_DATABASE = "http://tvplayersite.altervista.org/online/users.list"
    URL_ERROR_IMAGE = "http://tvplayersite.altervista.org/online/error.png"
    
    def __init__(self,config_directory="tvplayer") :
        home = os.path.expanduser('~')
        if not os.path.exists(home +'/.tvplayer'):
            os.makedirs(home +'/.tvplayer')
        if not os.path.exists(home +'/.tvplayer/la7image'):
            os.makedirs(home +'/.tvplayer/la7image')
        if not os.path.exists(home +'/.tvplayer/la7image/cult'):
            os.makedirs(home +'/.tvplayer/la7image/cult')
        self.config_dir = home +'/.tvplayer'
        if (os.path.exists(self.config_dir + '/personal_tv.list'))==False :
            personal=open(os.path.expanduser(self.config_dir + '/personal_tv.list'), 'w')
            personal.close()
        if (os.path.exists(self.config_dir + '/personal_radio.list'))==False :
            personal=open(os.path.expanduser(self.config_dir + '/personal_radio.list'), 'w')
            personal.close()
        if (os.path.exists(self.config_dir + '/error.png'))==False :
            errorfile = urllib.urlopen(self.URL_ERROR_IMAGE)
            localFile = open(os.path.expanduser(self.config_dir + '/error.png'), 'w+')
            localFile.write(errorfile.read())
            errorfile.close()
            localFile.close()
        
    def is_updated(self) :
        """
        La funzione verifica se sono già presenti file di Tv o Radio
        nella cartella di configurazione del programma.
        """
        if os.path.exists(self.config_dir + '/tv.list') :
            if os.path.exists(self.config_dir + '/radio.list') :
                self.primoAvvio()
                return True
        return False

    def default_player(self) :
        """
        La funzione verifica se è già presente il file di configurazione
        nella cartella di configurazione del programma, se si legge il player scelto.
        """
        if (os.path.isfile(self.config_dir + '/tv.config'))==False:
            print "Creo il file di configurazione"
            config=open(os.path.expanduser(self.config_dir + '/tv.config'), 'w')
            config.write("vlc#")
            config.close()
            return ["vlc",""]
        else:
	        config=open(os.path.expanduser(self.config_dir + '/tv.config'),"r")
	        player_config=config.readline()
	        config.close()
	        tmp=player_config.split('#')
	        if len(tmp)==1:
				tmp.append("")
				
	        if (tmp[0]=="vlc"):
		        return tmp
	        elif (tmp[0]=="totem"):
		        return tmp
	        elif (tmp[0]=="mplayer"):
		        return tmp
	        elif (tmp[0]=="mplayerRAI"):
		        return tmp
        return tmp

    def write_player_config(self, data, data2):
        config=open(os.path.expanduser(self.config_dir + '/tv.config'), 'w')
        config.write(data+"#"+data2)
        config.close()
       
    
    def download(self) :
        """
        Scarica i file contenenti le liste di canali.
        """
           
        # Fetching TV.
        tvwebfile = urllib.urlopen(self.URL_TV)
        localFile = open(os.path.expanduser(self.config_dir + '/tv.list'), 'w+')
        localFile.write(tvwebfile.read())
        tvwebfile.close()
        localFile.close()
        
        # Fetching Radio.
        radiowebfile = urllib.urlopen(self.URL_RADIO)
        localFile = open(os.path.expanduser(self.config_dir + '/radio.list'), 'w+')
        localFile.write(radiowebfile.read())
        radiowebfile.close()
        localFile.close()
        self.primoAvvio()

    def download_DATABASE(self) :
        """
        Scarica il database
        """
        datawebfile = urllib.urlopen(self.URL_DATABASE)
        localFile = open(os.path.expanduser(self.config_dir + '/database.list'), 'w+')
        localFile.write(datawebfile.read())
        datawebfile.close()
        localFile.close()

    def primoAvvio(self) :
        """
        Al primo avvio unisce i programmi di default alla lista personale
        """
        if (os.path.exists(self.config_dir + '/primoavvio'))==False :
            primoavvio=open(os.path.expanduser(self.config_dir + '/primoavvio'), 'w')
            primoavvio.close()
            tvfile = open(self.config_dir +'/tv.list', 'r')
            file=open(self.config_dir + '/personal_tv.list', 'a')
            for line in tvfile.readlines() :
                file.write(line)
            tvfile.close()
            file.close()

            radiofile = open(self.config_dir + '/radio.list', 'r')
            file=open(self.config_dir + '/personal_radio.list', 'a')
            result = {}
            for line in radiofile.readlines() :
                file.write(line)
            radiofile.close()
            file.close()
		
    def generatePersonalList(self,type) :
        """
        Effettua il parsing della lista dei canali Personali per generare
        un dizionario.
        """
        personalfile = open(self.config_dir + '/personal_'+type+'.list', 'r')
        result = {}
        for line in personalfile.readlines() :
            temp = line.split('#')
            name, addr = temp[0], temp[1]
            result[name] = addr[:-1]
        personalfile.close()
        return result
        
    def generateTGRList(self) :
        """
        Effettua il parsing della lista dei canali Personali per generare
        un dizionario.
        """
        tgrfile = open('regioni.list', 'r')
        result = {}
        for line in tgrfile.readlines() :
            temp = line.split('#')
            name, addr = temp[0], temp[1]
            result[name] = addr[:-1]
        tgrfile.close()
        return result

    def generateDatabaseList(self) :
        """
        Effettua il parsing della lista dei canali del Database per generare
        un dizionario.
        """
        datafile = open(self.config_dir +'/database.list', 'r')
        result = {}
        for line in datafile.readlines() :
            temp = line.split('#')
            name, addr = temp[0], temp[1]
            result[name+" #"+temp[2][:-1]] = addr[:-1]
        datafile.close()
        return result

    def removeitemPersonalList(self,link_remove,type) :
        """
        Rimuove il link scelto dalla lista personale
        """
        personalfile = open(self.config_dir + '/personal_'+type+'.list', 'r')
        result = {}
        for line in personalfile.readlines() :
            temp = line.split('#')
            name, addr = temp[0], temp[1]
            if link_remove != addr[:-1]:
                result[name] = addr[:-1]
        personalfile.close()

        personalfile = open(self.config_dir + '/personal_'+type+'.list', 'w')
        for i in result.keys() :
            personalfile.write(i+" #"+result[i]+"\n")
        personalfile.close()

